"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.colorize = void 0;
const node_util_1 = require("node:util");
const has_color_1 = require("./has-color");
const useColor = typeof process !== 'undefined' &&
    process.stdout.isTTY &&
    (0, has_color_1.hasColor)();
const cols = (color, text) => {
    const codes = node_util_1.inspect.colors[color];
    return `\x1b[${codes?.[0]}m${text}\x1b[${codes?.[1]}m`;
};
/**
 * Basic set of fns to add colors to console output in Node.
 *
 * Options:
 *
 * bold, italic, underline, inverse,
 * white, grey, black, blue, cyan, green, magenta, red, yellow
 * @example
 * console.log(colorize.bold(colorize.blue('foo'))) // => '\'\\u001b[34mfoo\\u001b[39m\''
 */
const _colorize = () => {
    const val = {};
    Object.keys(node_util_1.inspect.colors).forEach((color) => {
        val[color] = (text) => useColor ? cols(color, text) : text;
    });
    return val;
};
exports.colorize = _colorize();
