"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.each = void 0;
const is_array_like_1 = require("./is-array-like");
const iterateArray = (arr, fn) => {
    return arr.map((x, i) => fn(x, i.toString()));
};
const iterateObject = (obj, fn) => {
    const r = {};
    for (const prop in obj) {
        if (Object.hasOwn(obj, prop)) {
            r[prop] = fn(obj[prop], prop);
        }
    }
    return r;
};
/**
 * Takes an array or object
 * and a function, and runs the function
 * on each element
 * @example
 * each([ 'a', 'b', 'c' ], id) // => 'a'
 */
const each = (xs, fn) => {
    if ((0, is_array_like_1.isArrayLike)(xs)) {
        return iterateArray(xs, fn);
    }
    return iterateObject(xs, fn);
};
exports.each = each;
