"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.findPort = void 0;
const node_net_1 = require("node:net");
/**
 * Find next open port
 * @example
 * findPort(8000, (err, port) => console.log(`${port} is open`))
 */
const findPort = (port, cb) => {
    // eslint-disable-next-line @typescript-eslint/no-empty-function
    const server = (0, node_net_1.createServer)(() => { });
    const onListen = () => {
        server.close();
        cb(null, port);
    };
    const onError = (err) => {
        server.removeListener('listening', onListen);
        if (err.code && ['EADDRINUSE', 'EACCESS'].includes(err.code)) {
            return cb(err);
        }
        (0, exports.findPort)(port + 1, cb);
    };
    server.once('error', onError);
    server.once('listening', onListen);
    server.listen(port);
};
exports.findPort = findPort;
