"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.len = void 0;
const is_array_like_1 = require("./is-array-like");
const is_map_1 = require("./is-map");
const is_object_1 = require("./is-object");
const is_set_1 = require("./is-set");
const is_string_1 = require("./is-string");
const is_function_1 = require("./is-function");
const is_number_1 = require("./is-number");
/**
 * Get length of element
 *
 * Works for array, object, string, set, map, and function
 * @example
 * len('foo') // => 3
 * len([ 1, 2 ]) => 2
 * len((a, b) => a + b) // => 2
 */
const len = (val) => {
    if ((0, is_number_1.isNumber)(val))
        return val;
    if (Array.isArray(val) || (0, is_string_1.isString)(val) || (0, is_function_1.isFunction)(val) || (0, is_array_like_1.isArrayLike)(val))
        return val.length;
    if ((0, is_map_1.isMap)(val) || (0, is_set_1.isSet)(val))
        return val.size;
    // eslint-disable-next-line @typescript-eslint/no-unsafe-argument
    if ((0, is_object_1.isObject)(val))
        return Object.keys(val).length;
    return 0;
};
exports.len = len;
