"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.safeGet = void 0;
const id_1 = require("./id");
/**
 * Like `_.get`: takes an access string and an optional fallback,
 * then an object
 * @example
 * safeGet('a.b.c')({ a: { b: { c: 'd' } } }) // => 'd'
 * safeGet('a.b.e')({ a: { b: { c: 'd' } } }) // => undefined
 * safeGet('a.b.e', 'f')({ a: { b: { c: 'd' } } }) // => 'f'
 */
const safeGet = (path, fallback) => (obj) => path
    .split(/[.[\]]/)
    .filter(id_1.id)
    .reduce((o, prop) => o?.[prop], obj) || fallback;
exports.safeGet = safeGet;
