"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.store = void 0;
/**
 * A very simple store implementation (think Redux-like)
 * @example
 * const state = store()
 * state.subscribe((next, prev) => next.foo)
 * state.update({ foo: 'bar' })
 */
const store = (state = {}) => {
    const ls = [];
    return {
        subscribe: (l) => {
            ls.push(l);
        },
        unsubscribe: (l) => {
            if (ls.includes(l)) {
                ls.splice(ls.indexOf(l), 1);
            }
        },
        update: (n) => {
            const p = state;
            state = Object.assign({}, p, typeof n === 'function' ? n(p) : n);
            for (let i = 0; i < ls.length; i++) {
                ls[i](state, p);
            }
        },
    };
};
exports.store = store;
