"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.typeOf = void 0;
const is_set_1 = require("./is-set");
const is_map_1 = require("./is-map");
const is_date_1 = require("./is-date");
const is_reg_exp_1 = require("./is-reg-exp");
/**
 * Enhanced `typeof`
 * @example
 * typeOf('a') // => 'string'
 * typeOf(new Date()) // => 'date'
 */
const typeOf = (a) => {
    if (typeof a === 'object') {
        if (a === null)
            return 'null';
        if (a && a.nodeType === 1)
            return 'dom';
        if (Array.isArray(a))
            return 'array';
        if ((0, is_date_1.isDate)(a))
            return 'date';
        if ((0, is_reg_exp_1.isRegExp)(a))
            return 'regexp';
        if ((0, is_set_1.isSet)(a))
            return 'set';
        if ((0, is_map_1.isMap)(a))
            return 'map';
        return 'object';
    }
    return typeof a;
};
exports.typeOf = typeOf;
